/*
 * Copyright (c) 2017 Razeware LLC
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */

package com.raywenderlich.continents


import android.view.View
import android.widget.ArrayAdapter
import android.widget.Spinner
import android.widget.TextView
import android.app.Activity
import android.os.Bundle
import android.widget.Toolbar
import android.widget.AdapterView

class MainActivity : Activity(), ContinentSelectedListener {

  private lateinit var title: TextView
  private lateinit var orderContinents: Spinner
  private var mainFragment: MainFragment? = null
  private var continentMap: MutableMap<String, Continent> = HashMap()

  val continentNames = arrayOf("Asia", "Africa", "Australia", "Antarctica", "Europe",
      "North America", "South America")

  private val continentDescs: Array<String> = arrayOf(
      """
            |Asia is the Earth's largest and most populous continent. It covers 8.7% of
            |Earth's total surface area. As of 2013, it had a population of 4.3 billion.
            |It consists of 47 countries.""".trimMargin(),
      """
            |Africa is the Earth's second largest and second most populous continent.
            |It covers 6% of Earth's total surface area.
            |As of 2013, it had a population of 1.1 billion. It consists of 54 countries.""".trimMargin(),
      """
            |Australia is both a country and a continent.
            |As of 2013, it had a population of 23 million.""".trimMargin(),
      """
            |Antarctica is the Earth's southernmost continent. It is the fifth largest continent.
            |About 98% of Antarctica is covered by ice.""".trimMargin(),
      """
            |Europe is the Earth's second smallest continent. It covers 2% of Earth's surface area.
            |As of 2013, it had a population of 742.5 million. It consists of 50 countries.""".trimMargin(),
      """
            |North America is the Earth's third largest continent and fourth most populous continent.
            |It covers about 16.5% of the Earth's surface area.
            |As of 2013, it had a population of about 565 million.
            |It consists of 23 countries.""".trimMargin(),
      """
            |South America is the Earth's fourth largest continent and fifth most populous continent.
            |As of 2011, it had a population of about 385.7 million. It consists of 12 countries""".trimMargin()
  )

  private val imageResources = arrayOf(R.drawable.asia, R.drawable.africa, R.drawable
      .australia, R.drawable.antarctica, R.drawable.europe, R.drawable.north_america, R.drawable
      .south_america)

  override fun onCreate(savedInstanceState: Bundle?) {
    super.onCreate(savedInstanceState)
    setContentView(R.layout.activity_main)

    for ((i, name) in continentNames.withIndex()) {
      val continent = Continent(name, continentDescs[i], imageResources[i])
      continentMap.put(name, continent)
    }

    val toolbar = findViewById<Toolbar>(R.id.toolbar)
    title = toolbar.findViewById(R.id.title)
    orderContinents = toolbar.findViewById(R.id.toolbar_spinner)
    val adapter = ArrayAdapter<String>(this,
        android.R.layout.simple_spinner_item, arrayOf("A - Z", "Z - A"))
    adapter.setDropDownViewResource(android.R.layout.simple_spinner_dropdown_item)
    orderContinents.adapter = adapter
    orderContinents.onItemSelectedListener = object : AdapterView.OnItemSelectedListener {
      override fun onItemSelected(parent: AdapterView<*>, view: android.view.View,
                                  position: Int, id: Long) {
        when (position) {
          0 -> {
            continentNames.sort()
            mainFragment?.updateContinents(continentNames)
          }
          1 -> {
            continentNames.reverse()
            mainFragment?.updateContinents(continentNames)
          }
          else -> {
          }
        }

      }

      override fun onNothingSelected(parent: android.widget.AdapterView<*>) {}
    }

    setActionBar(toolbar)
    goToContinentList()
  }

  override fun onOptionsItemSelected(item: android.view.MenuItem): Boolean {
    goToContinentList()
    return true
  }

  override fun onContinentSelected(selectedContinent: String) {
    val continent = continentMap[selectedContinent]
    continent?.let {
      title.text = continent.name
      orderContinents.visibility = View.INVISIBLE
      actionBar?.setDisplayHomeAsUpEnabled(true)

      val descriptionFragment = DescriptionFragment.newInstance(continent)

      fragmentManager
          .beginTransaction()
          .replace(R.id.frameLayout, descriptionFragment)
          .addToBackStack(null)
          .commit()
    }

  }

  private fun goToContinentList() {
    actionBar?.setDisplayHomeAsUpEnabled(false)
    title.text = getString(R.string.continents)
    orderContinents.visibility = View.VISIBLE
    mainFragment = MainFragment.newInstance(continentNames)
    fragmentManager
        .beginTransaction()
        .replace(R.id.frameLayout, mainFragment)
        .commit()
  }

  override fun onBackPressed() {
    super.onBackPressed()
    title.text = getString(R.string.continents)
    actionBar?.setDisplayHomeAsUpEnabled(false)
  }
}
