/*
 * Copyright (c) 2017 Razeware LLC
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */

package com.raywenderlich.continents

import android.app.Fragment
import android.content.Context
import android.os.Bundle
import android.view.ViewGroup
import android.view.LayoutInflater
import android.view.View
import android.widget.ArrayAdapter
import android.widget.ListView


class MainFragment : Fragment() {

  private lateinit var listView: ListView
  private lateinit var listAdapter: ArrayAdapter<String>
  private lateinit var continents: Array<String>
  private var listener: ContinentSelectedListener? = null

  companion object {
    private const val ARG_PARAM1 = "continentNames"

    fun newInstance(continents: Array<String>): MainFragment {
      val fragment = MainFragment()
      val args = Bundle().apply {
        putStringArray(ARG_PARAM1, continents)
      }
      fragment.arguments = args
      return fragment
    }
  }

  override fun onCreate(savedInstanceState: Bundle?) {
    super.onCreate(savedInstanceState)
    arguments?.let {
      continents = it.getStringArray(ARG_PARAM1)
    }
  }

  override fun onCreateView(inflater: LayoutInflater, container: ViewGroup?,
                            savedInstanceState: Bundle?): View? {
    val view = inflater.inflate(R.layout.fragment_main, container, false)

    listView = view.findViewById(R.id.mainListView)

    // Create ArrayAdapter using the continent list.
    listAdapter = ArrayAdapter(this.activity, android.R.layout.simple_list_item_1, continents)
    listView.adapter = listAdapter
    listView.setOnItemClickListener { _, _, position, _ ->
      if (listener == null) {
        listener = activity as ContinentSelectedListener
      }
      listener?.onContinentSelected(continents[position])
    }
    return view
  }

  override fun onAttach(context: Context) {
    super.onAttach(context)
    try {
      listener = context as ContinentSelectedListener
    } catch (e: ClassCastException) {
      throw ClassCastException("$context must implement ContinentSelectedListener")
    }
  }

  fun updateContinents(continentList: Array<String>) {
    continents = continentList
    listAdapter = android.widget.ArrayAdapter(this.activity, android.R.layout
        .simple_list_item_1, continents)

    listView.adapter = listAdapter
    listAdapter.notifyDataSetChanged()
  }

  override fun onDetach() {
    super.onDetach()
    listener = null
  }
}